<?php if (!defined('OT_VERSION')) exit('No direct script access allowed');
/**
 * OptionTree Admin
 *
 * @package     WordPress
 * @subpackage  OptionTree
 * @since       1.0.0
 * @author      Derek Herman
 */
class OT_Admin
{
  private $table_name = NULL;
  private $version = NULL;
  private $option_array = array();

  function __construct() 
  {
    global $table_prefix;

    $this->table_name = $table_prefix . 'fuji_option_tree';
    $this->version = OT_VERSION;
    $this->option_array = $this->option_tree_data();
  }

  /**
   * Initiate Plugin & setup main options
   *
   * @uses get_option()
   * @uses add_option()
   * @uses option_tree_activate()
   * @uses wp_redirect()
   * @uses admin_url()
   *
   * @access public
   * @since 1.0.0
   *
   * @return bool
   */
  function option_tree_init() 
  {
    // check for activation
    $check = get_option( 'option_tree_activation' );

    // redirect on activation
    if ($check != "set" && $this->option_array[0]) 
    {
      // set blank option values
      foreach ( $this->option_array as $value ) 
      {
          $key = $value->item_id;
        $new_options[$key] = '';
      }

      // add theme options
      add_option( 'option_tree', $new_options );
      add_option( 'option_tree_activation', 'set');

      // load DB activation function if updating plugin
      $this->option_tree_activate();

      // Redirect
      wp_redirect( admin_url().'admin.php?page=option_tree&xml=true' );
    }
    return false;
  }

  /**
   * Plugin Table Structure
   *
   * @access public
   * @since 1.0.0
   *
   * @param string $type
   *
   * @return string
   */
  function option_tree_table( $type = '')
  {
    if ( $type == 'create' ) 
    {
      $sql = "CREATE TABLE {$this->table_name} (
            id mediumint(9) NOT NULL AUTO_INCREMENT PRIMARY KEY,
            item_id VARCHAR(50) NOT NULL,
            item_title VARCHAR(100) NOT NULL,
            item_desc LONGTEXT,
            item_type VARCHAR(30) NOT NULL,
            item_options VARCHAR(250) DEFAULT NULL,
            item_sort mediumint(9) DEFAULT '0' NOT NULL,
            UNIQUE KEY (item_id)
      ) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;";
    }
    return $sql;
  }

  /*
   * Plugin Activation
   *
   * @uses get_var()
   * @uses get_option()
   * @uses dbDelta()
   * @uses option_tree_table()
   * @uses option_tree_default_data()
   * @uses update_option()
   * @uses add_option()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_activate() 
  {
    global $wpdb;

    // check for table
    $new_installation = $wpdb->get_var( "show tables like '$this->table_name'" ) != $this->table_name;

    // check for installed version
      $installed_ver = get_option( 'option_tree_version' );

    // add/update table
      if ( $installed_ver != $this->version ) 
      {
      // run query
          require_once( ABSPATH . 'wp-admin/includes/upgrade.php');
          dbDelta( $this->option_tree_table( 'create' ) );
    }

    // new install default data
    if ( $new_installation ) 
    {
      $this->option_tree_default_data();
    }

    // New Version Update
    if ( $installed_ver != $this->version ) 
    {
      update_option( 'option_tree_version', $this->version );
    } 
    else if ( !$installed_ver ) 
    {
      add_option( 'option_tree_version', $this->version );
    }
  }

  /**
   * Plugin Deactivation delete options
   *
   * @uses delete_option()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_deactivate() 
  {
    // remove activation check & version
    delete_option( 'option_tree_activation' );
    delete_option( 'option_tree_version' );
  }

  /**
   * Plugin Activation Default Data
   *
   * @uses query()
   * @uses prepare()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_default_data() 
  {
      global $wpdb;

    $new_installation = $wpdb->get_var( "show tables like '$this->table_name'" ) != $this->table_name;

    $ot_xml_file = OT_PLUGIN_DIR . "/theme-options.xml";           
    $rawdata = '<?xml version="1.0"?>
<wp_fuji_option_tree>
  <row>
    <id>1</id>
    <item_id>general_default</item_id>
    <item_title>Page Elements</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>1</item_sort>
  </row>
  <row>
    <id>2</id>
    <item_id>background</item_id>
    <item_title>Website background</item_title>
    <item_desc>Choose which type of background to use for the website. When done, choose the color or upload the image in one of the options below.</item_desc>
    <item_type>radio</item_type>
    <item_options>Solid color,Repeated texture,Full-size image</item_options>
    <item_sort>2</item_sort>
  </row>
  <row>
    <id>3</id>
    <item_id>background_color</item_id>
    <item_title>Website background: color fill</item_title>
    <item_desc>If you wish to have a solid single-color background, choose the color here. This setting will override the texture or image background! The default background color is #444444.</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>3</item_sort>
  </row>
  <row>
    <id>4</id>
    <item_id>background_texture</item_id>
    <item_title>Website background: texture</item_title>
    <item_desc>If you wish to use a texture as the website background, please upload the image here. The pattern will automatically be repeated to fill the entire background.</item_desc>
    <item_type>upload</item_type>
    <item_options></item_options>
    <item_sort>4</item_sort>
  </row>
  <row>
    <id>143</id>
    <item_id>background_image</item_id>
    <item_title>Website background: image</item_title>
    <item_desc>Upload the background image here. To display a full-size image background, the respective option needs to be chosen from the &amp;quot;Website background&amp;quot; feature above.  Recommended minimal dimensions for a background image are 2560x1600 pixels; smaller images may get stretched and pixelated on large screens.</item_desc>
    <item_type>upload</item_type>
    <item_options></item_options>
    <item_sort>5</item_sort>
  </row>
  <row>
    <id>6</id>
    <item_id>favicon</item_id>
    <item_title>Custom favicon</item_title>
    <item_desc>Upload a custom image to use as the website&amp;#039;s favicon (the small icon that appears on the browser tab and in the favourites folder). Recommended formats are &amp;quot;.ico&amp;quot; and &amp;quot;.png&amp;quot;.</item_desc>
    <item_type>upload</item_type>
    <item_options></item_options>
    <item_sort>6</item_sort>
  </row>
  <row>
    <id>5</id>
    <item_id>logo</item_id>
    <item_title>Logo</item_title>
    <item_desc>Upload your own logo image here.</item_desc>
    <item_type>upload</item_type>
    <item_options></item_options>
    <item_sort>7</item_sort>
  </row>
  <row>
    <id>118</id>
    <item_id>retina_logo</item_id>
    <item_title>Retina logo</item_title>
    <item_desc>Upload here the retina version of the logo (image file either 2 times as wide and high as the normal logo - or with a 2 times higher dpi). Please name your file exactly as the original logo, adding &amp;quot;@2x&amp;quot; in the end, e.g.:
logo.jpg  -&amp;gt;  logo@2x.jpg.</item_desc>
    <item_type>upload</item_type>
    <item_options></item_options>
    <item_sort>8</item_sort>
  </row>
  <row>
    <id>138</id>
    <item_id>hide_logo</item_id>
    <item_title>Hide logo on portfolio pages</item_title>
    <item_desc>Check this to hide the logo on portfolio and portfolio tag pages (i.e. masonry pages).</item_desc>
    <item_type>checkbox</item_type>
    <item_options>Yes</item_options>
    <item_sort>9</item_sort>
  </row>
  <row>
    <id>140</id>
    <item_id>logo_inside</item_id>
    <item_title>Always display the logo inside the header section</item_title>
    <item_desc>Check this option if you want the logo to always display inside the top header section, moving the menu to the right. If this is not checked, the logo will slide to the left above the icon menu if there is an icon menu.</item_desc>
    <item_type>checkbox</item_type>
    <item_options>Yes</item_options>
    <item_sort>10</item_sort>
  </row>
  <row>
    <id>141</id>
    <item_id>logo_width</item_id>
    <item_title>Logo width (only if previous option is checked).</item_title>
    <item_desc>Input the desired width of the logo. The default is 70px.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>11</item_sort>
  </row>
  <row>
    <id>142</id>
    <item_id>header_height</item_id>
    <item_title>Header section height</item_title>
    <item_desc>Input the header section height in pixels (e.g. &amp;quot;100&amp;quot;, without quotes). Leave this blank to keep the default height, 50px. Note that on smaller screens the header may become even taller to accommodate all elements.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>12</item_sort>
  </row>
  <row>
    <id>134</id>
    <item_id>header_search</item_id>
    <item_title>Display search box in the header</item_title>
    <item_desc>Check this option if you wish to display a search box in the right corner of the header.</item_desc>
    <item_type>checkbox</item_type>
    <item_options>Yes</item_options>
    <item_sort>13</item_sort>
  </row>
  <row>
    <id>8</id>
    <item_id>hide_titles</item_id>
    <item_title>Hide page titles on pages</item_title>
    <item_desc>Check this option to hide the page titles on pages (note that post titles will still be displayed e.g. in the blog).</item_desc>
    <item_type>checkbox</item_type>
    <item_options>Yes</item_options>
    <item_sort>14</item_sort>
  </row>
  <row>
    <id>10</id>
    <item_id>hide_category</item_id>
    <item_title>Hide &amp;quot;category&amp;quot; prefix on category pages</item_title>
    <item_desc>Check this option if you want to hide the &amp;quot;Category:&amp;quot; prefix from the page titles on category pages.</item_desc>
    <item_type>checkbox</item_type>
    <item_options>Yes</item_options>
    <item_sort>15</item_sort>
  </row>
  <row>
    <id>11</id>
    <item_id>author</item_id>
    <item_title>Display author information in posts</item_title>
    <item_desc>Check this if you want to display author credentials at the bottom of every post, above the comments (if active).</item_desc>
    <item_type>checkbox</item_type>
    <item_options>Yes</item_options>
    <item_sort>16</item_sort>
  </row>
  <row>
    <id>12</id>
    <item_id>to_top</item_id>
    <item_title>Scroll to top button</item_title>
    <item_desc>If you wish to have a custom image for the scroll to top button, please upload it here. Maximum dimensions are 51x51 pixels</item_desc>
    <item_type>upload</item_type>
    <item_options></item_options>
    <item_sort>17</item_sort>
  </row>
  <row>
    <id>13</id>
    <item_id>copyright</item_id>
    <item_title>Copyright text</item_title>
    <item_desc>Enter the text to be placed in the copyright area in the bottom of the footer (below footer widgets). You can use HTML here.</item_desc>
    <item_type>textarea</item_type>
    <item_options>6</item_options>
    <item_sort>18</item_sort>
  </row>
  <row>
    <id>112</id>
    <item_id>portfolio_heading</item_id>
    <item_title>Portfolio Page</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>19</item_sort>
  </row>
  <row>
    <id>111</id>
    <item_id>boxdim</item_id>
    <item_title>Portfolio page items: box dimensions</item_title>
    <item_desc>Input the desired width and height (in pixels) for the square portfolio blocks, e.g. &amp;quot;300&amp;quot; (without quotes). This value will be applied to the &amp;quot;normal&amp;quot; box size; the &amp;quot;large&amp;quot; size will automatically be made twice as large. Leave this blank to keep the default value (260px).</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>20</item_sort>
  </row>
  <row>
    <id>113</id>
    <item_id>boxmar</item_id>
    <item_title>Portfolio page items: box margins</item_title>
    <item_desc>Input the desired width (in pixels) for the blank spaces between boxes on the portfolio page, e.g. &amp;quot;25&amp;quot; (without quotes). Leave this blank to keep the default value (16px).</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>21</item_sort>
  </row>
  <row>
    <id>9</id>
    <item_id>ppp</item_id>
    <item_title>Portfolio items per page</item_title>
    <item_desc>Input the number of portfolio items (projects) to display per portfolio page. If the total number of projects is larger than this limit, pagination links will appear automatically at the bottom of the pages. Default value is 20.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>22</item_sort>
  </row>
  <row>
    <id>144</id>
    <item_id>portfolio_orderby</item_id>
    <item_title>Order of portfolio items</item_title>
    <item_desc>Choose the method for ordering portfolio items on the portfolio page. Default is date created.</item_desc>
    <item_type>select</item_type>
    <item_options>Date created,Date modified,Comment count</item_options>
    <item_sort>23</item_sort>
  </row>
  <row>
    <id>145</id>
    <item_id>portfolio_order</item_id>
    <item_title>Ascending or descending?</item_title>
    <item_desc>Choose whether the portfolio items should be ordered in ascending or descending fashion. Default is descending.</item_desc>
    <item_type>select</item_type>
    <item_options>Descending,Ascending</item_options>
    <item_sort>24</item_sort>
  </row>
  <row>
    <id>137</id>
    <item_id>disable_captions</item_id>
    <item_title>Portfolio item captions</item_title>
    <item_desc>Choose the preferred way to handle portfolio item captions (sourced from excerpts). Default is &amp;quot;show on mouse hover&amp;quot;.</item_desc>
    <item_type>select</item_type>
    <item_options>Never show,Show on mouse hover,Always show</item_options>
    <item_sort>25</item_sort>
  </row>
  <row>
    <id>133</id>
    <item_id>show_overlays</item_id>
    <item_title>Display project type icons in portfolio</item_title>
    <item_desc>Check this option to display overlay icons indicating the type of projects (standard project, image, or video) on clickable project types in portfolio.</item_desc>
    <item_type>checkbox</item_type>
    <item_options>Yes</item_options>
    <item_sort>26</item_sort>
  </row>
  <row>
    <id>7</id>
    <item_id>portfoliometa</item_id>
    <item_title>Display meta information on portfolio item pages</item_title>
    <item_desc>Check this to display meta information (project date, author, tags, and comments) on portfolio and single project pages.</item_desc>
    <item_type>checkbox</item_type>
    <item_options>Yes</item_options>
    <item_sort>27</item_sort>
  </row>
  <row>
    <id>14</id>
    <item_id>stickmenu</item_id>
    <item_title>Icon Menu</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>28</item_sort>
  </row>
  <row>
    <id>139</id>
    <item_id>icons_show</item_id>
    <item_title>Show icons only on portfolio pages</item_title>
    <item_desc>Check this if you wish to hide the icons on all pages except the portfolio page and the portfolio tag archives.</item_desc>
    <item_type>checkbox</item_type>
    <item_options>Yes</item_options>
    <item_sort>29</item_sort>
  </row>
  <row>
    <id>15</id>
    <item_id>icons</item_id>
    <item_title>Icon menu items</item_title>
    <item_desc>This section allows you to create the icon menu - a series of vertically stacked images of your choosing located to the left of the content; each with a customizable link destination, icon, and hover icon, and a possible option to filter out a specific portfolio tag.</item_desc>
    <item_type>slider</item_type>
    <item_options></item_options>
    <item_sort>30</item_sort>
  </row>
  <row>
    <id>16</id>
    <item_id>typography</item_id>
    <item_title>Typography</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>31</item_sort>
  </row>
  <row>
    <id>17</id>
    <item_id>font_header</item_id>
    <item_title>Headings font</item_title>
    <item_desc>Input Google Font name for the heading font, e.g. &amp;quot;Open Sans&amp;quot; (without quotes). You can preview Google Fonts here: http://www.google.com/webfonts.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>32</item_sort>
  </row>
  <row>
    <id>18</id>
    <item_id>font_menu</item_id>
    <item_title>Menu item font</item_title>
    <item_desc>Input Google Font name for the menu font, e.g. &amp;quot;Open Sans&amp;quot; (without quotes). You can preview Google Fonts here: http://www.google.com/webfonts.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>33</item_sort>
  </row>
  <row>
    <id>125</id>
    <item_id>primary_menu_text_size</item_id>
    <item_title>Primary menu item font size</item_title>
    <item_desc>Set the font size for the primary (left) menu text. Leave this blank to keep the default size (22px).</item_desc>
    <item_type>input</item_type>
    <item_options>8,9,10,11,12,13,14,16,18,24,28,26,48</item_options>
    <item_sort>34</item_sort>
  </row>
  <row>
    <id>19</id>
    <item_id>font_body</item_id>
    <item_title>Body font</item_title>
    <item_desc>Input Google Font name for the body font, e.g. &amp;quot;Open Sans&amp;quot; (without quotes). You can preview Google Fonts here: http://www.google.com/webfonts.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>35</item_sort>
  </row>
  <row>
    <id>20</id>
    <item_id>body_text_size</item_id>
    <item_title>Body font size</item_title>
    <item_desc>Set the font size for the body text (all text except for headings). Leave this blank to keep the default size (16px).</item_desc>
    <item_type>input</item_type>
    <item_options>8,9,10,11,12,13,14,16,18,24,28,26,48</item_options>
    <item_sort>36</item_sort>
  </row>
  <row>
    <id>128</id>
    <item_id>body_line_height</item_id>
    <item_title>Body line height</item_title>
    <item_desc>Select the line height for the body text (all text except for headings). Leave this blank to keep the default height (24px).</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>37</item_sort>
  </row>
  <row>
    <id>126</id>
    <item_id>large_box_text_size</item_id>
    <item_title>Large portfolio box font size</item_title>
    <item_desc>Set the font size for the text in large portfolio boxes. Leave this blank to keep the default size (40px).</item_desc>
    <item_type>input</item_type>
    <item_options>8,9,10,11,12,13,14,16,18,24,28,26,48</item_options>
    <item_sort>38</item_sort>
  </row>
  <row>
    <id>127</id>
    <item_id>large_box_text_line</item_id>
    <item_title>Large portfolio box line height</item_title>
    <item_desc>Set the line height for the large portfolio boxes. Leave this blank to keep the default height (50px).</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>39</item_sort>
  </row>
  <row>
    <id>21</id>
    <item_id>header_social_heading</item_id>
    <item_title>Header Social Icons</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>40</item_sort>
  </row>
  <row>
    <id>135</id>
    <item_id>icon_color</item_id>
    <item_title>Header social icons color</item_title>
    <item_desc>Choose the color for the header social icons. Leave this blank if you wish to keep the default color (#CCCCCC).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>41</item_sort>
  </row>
  <row>
    <id>22</id>
    <item_id>header_social_target</item_id>
    <item_title>Open social links in new tab/window?</item_title>
    <item_desc>Choose whether the social links in the header will open pages in the same tab or window as the website, or in a new one (the latter is default).</item_desc>
    <item_type>radio</item_type>
    <item_options>New tab/window,Same tab/window</item_options>
    <item_sort>42</item_sort>
  </row>
  <row>
    <id>23</id>
    <item_id>header_facebook</item_id>
    <item_title>Facebook profile/page:</item_title>
    <item_desc>Enter the link to your Facebook profile or page (e.g. http://www.facebook.com/satoristudio.net).</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>43</item_sort>
  </row>
  <row>
    <id>24</id>
    <item_id>header_twitter</item_id>
    <item_title>Twitter channel:</item_title>
    <item_desc>Enter the link to your Twitter channel (e.g. https://twitter.com/satoristudionet).</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>44</item_sort>
  </row>
  <row>
    <id>25</id>
    <item_id>header_google_plus</item_id>
    <item_title>Google+ profile/page:</item_title>
    <item_desc>Enter the link to your Google+ profile or page.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>45</item_sort>
  </row>
  <row>
    <id>26</id>
    <item_id>header_linkedin</item_id>
    <item_title>LinkedIn profile/page:</item_title>
    <item_desc>Enter the link to your LinkedIn profile/page (e.g. http://lv.linkedin.com/in/ashekhirev/).</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>46</item_sort>
  </row>
  <row>
    <id>27</id>
    <item_id>header_pinterest</item_id>
    <item_title>Pinterest page:</item_title>
    <item_desc>Enter the link to your Pinterest page.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>47</item_sort>
  </row>
  <row>
    <id>28</id>
    <item_id>header_flickr</item_id>
    <item_title>Flickr stream:</item_title>
    <item_desc>Enter the link to your Flickr stream.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>48</item_sort>
  </row>
  <row>
    <id>29</id>
    <item_id>header_rss</item_id>
    <item_title>RSS feed:</item_title>
    <item_desc>Enter the URL of your RSS feed (e.g. http://satoristudio.net/tokyo/feed/).</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>49</item_sort>
  </row>
  <row>
    <id>30</id>
    <item_id>header_youtube</item_id>
    <item_title>Youtube channel:</item_title>
    <item_desc>Enter the link to your Youtube channel.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>50</item_sort>
  </row>
  <row>
    <id>32</id>
    <item_id>header_custom_social_1</item_id>
    <item_title>Custom social network 1:</item_title>
    <item_desc>In case you need to include a service not listed above, please enter the link to your destination here.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>51</item_sort>
  </row>
  <row>
    <id>33</id>
    <item_id>header_custom_social_1_icon</item_id>
    <item_title>Icon for custom social network 1:</item_title>
    <item_desc>Upload the icon for the custom destination you entered above. Recommended icon format is transparent png, recommended height is 22px.</item_desc>
    <item_type>upload</item_type>
    <item_options></item_options>
    <item_sort>52</item_sort>
  </row>
  <row>
    <id>34</id>
    <item_id>header_custom_social_2</item_id>
    <item_title>Custom social network 2:</item_title>
    <item_desc>In case you need to include another service not listed above, please enter the link to your destination here.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>53</item_sort>
  </row>
  <row>
    <id>35</id>
    <item_id>header_custom_social_2_icon</item_id>
    <item_title>Icon for custom social network 2:</item_title>
    <item_desc>Upload the icon for the custom destination you entered above. Recommended icon format is transparent png, recommended height is 22px.</item_desc>
    <item_type>upload</item_type>
    <item_options></item_options>
    <item_sort>54</item_sort>
  </row>
  <row>
    <id>36</id>
    <item_id>style_header</item_id>
    <item_title>Style: Header</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>55</item_sort>
  </row>
  <row>
    <id>136</id>
    <item_id>menu_background</item_id>
    <item_title>Header background color</item_title>
    <item_desc>Choose the background color for the header (i.e. the top area which contains the primary menu. Leave this blank to keep the default color (#666666).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>56</item_sort>
  </row>
  <row>
    <id>37</id>
    <item_id>header_menu_color</item_id>
    <item_title>Menu text color</item_title>
    <item_desc>Choose the text color of the main menu. Leave blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>57</item_sort>
  </row>
  <row>
    <id>38</id>
    <item_id>header_menu_text_hover</item_id>
    <item_title>Menu hover text color</item_title>
    <item_desc>Choose the text color of the main menu items on mouse over. Leave this blank if you wish to keep the default color (#B9CF9A).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>58</item_sort>
  </row>
  <row>
    <id>114</id>
    <item_id>header_menu_active</item_id>
    <item_title>Menu active item color</item_title>
    <item_desc>Choose the text color of the active main menu item. Leave this blank if you wish to keep the default color (#B9CF9A).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>59</item_sort>
  </row>
  <row>
    <id>115</id>
    <item_id>header_menu_submenu_bck</item_id>
    <item_title>Menu submenu background</item_title>
    <item_desc>Choose the background color of the main menu submenus. Leave this blank if you wish to keep the default color (#333333).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>60</item_sort>
  </row>
  <row>
    <id>116</id>
    <item_id>header_menu_submenu_border</item_id>
    <item_title>Menu submenu item border</item_title>
    <item_desc>Choose the border color between the main menu&amp;#039;s submenu items. Leave this blank if you wish to keep the default color (#414141).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>61</item_sort>
  </row>
  <row>
    <id>39</id>
    <item_id>stick_bck</item_id>
    <item_title>Mobile menu item background</item_title>
    <item_desc>Choose the background color of the mobile menu items (appears on smartphone screens). Leave this blank if you wish to keep the default background color (#666666).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>62</item_sort>
  </row>
  <row>
    <id>40</id>
    <item_id>stick_hover</item_id>
    <item_title>Mobile menu item mouseover color</item_title>
    <item_desc>Choose the background color of the mobile menu items on mouse over (appears on smartphone screens). Leave this blank if you wish to keep the default background color (#999999).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>63</item_sort>
  </row>
  <row>
    <id>41</id>
    <item_id>content_and_widgets</item_id>
    <item_title>Style: Content, Widgets</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>64</item_sort>
  </row>
  <row>
    <id>130</id>
    <item_id>main_background</item_id>
    <item_title>Content background color</item_title>
    <item_desc>Choose the background color for website content, including content areas of posts and pages, portfolio items, and portfolio filters. Leave this blank if you wish to keep the default background color (#666666).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>65</item_sort>
  </row>
  <row>
    <id>131</id>
    <item_id>filter_hover_background</item_id>
    <item_title>Portfolio filter background on mouse over</item_title>
    <item_desc>Choose the background color for the portfolio filter items on mouse hover. Leave this blank if you wish to keep the default color (#888888).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>66</item_sort>
  </row>
  <row>
    <id>132</id>
    <item_id>portfolio_filter_text</item_id>
    <item_title>Portfolio filter text color</item_title>
    <item_desc>Choose the text color for portfolio filter labels. Leave this blank to keep the default color (#B9CF9A).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>67</item_sort>
  </row>
  <row>
    <id>43</id>
    <item_id>body_headings</item_id>
    <item_title>Body heading text color</item_title>
    <item_desc>Choose the text color main body headings, including page headings and portfolio page headings. Leave blank if you wish to keep the default  color (#DDDDDD).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>68</item_sort>
  </row>
  <row>
    <id>44</id>
    <item_id>body_headings_thickness</item_id>
    <item_title>Body heading - text thickness</item_title>
    <item_desc>Choose the thickness of the heading text: 400 is normal thickness, 700 corresponds to the &amp;quot;bold&amp;quot; style. Note: not all Google fonts support all values. Leave blank if you wish to keep the default value (400).</item_desc>
    <item_type>select</item_type>
    <item_options>200,400,500,600,700,900</item_options>
    <item_sort>69</item_sort>
  </row>
  <row>
    <id>45</id>
    <item_id>subheading_color</item_id>
    <item_title>Body subheading text color</item_title>
    <item_desc>Choose the text color of headings in the comments and post-author sections of the posts. This will also apply to the subheading on the search results page. Please note that this setting will override the &amp;quot;Body heading text color&amp;quot; option above. Leave blank if you wish to keep the default color (#DDDDDD).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>70</item_sort>
  </row>
  <row>
    <id>46</id>
    <item_id>body_color</item_id>
    <item_title>Body text color</item_title>
    <item_desc>Choose the text color in the body section of the website (content and widgets). Leave blank if you wish to keep the default color (#999999).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>71</item_sort>
  </row>
  <row>
    <id>47</id>
    <item_id>body_links</item_id>
    <item_title>Body link - text color</item_title>
    <item_desc>Choose the color of the hyperlinks in the body section of the website (content and widgets). Leave blank if you wish to keep the default color (#A7E085).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>72</item_sort>
  </row>
  <row>
    <id>48</id>
    <item_id>body_links_hover</item_id>
    <item_title>Body link hover - text color</item_title>
    <item_desc>Choose the color of the hyperlinks in the body section of the website (content and widgets) on mouse-over. Leave blank if you wish to keep the default color (#99FF66).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>73</item_sort>
  </row>
  <row>
    <id>49</id>
    <item_id>comments_borders</item_id>
    <item_title>Body borders color</item_title>
    <item_desc>Choose the color for the borders between posts in the blog, portfolio items in the portfolio, and comments section of posts and project items. Leave this blank if you wish to keep the default color (#777777).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>74</item_sort>
  </row>
  <row>
    <id>123</id>
    <item_id>tag_text</item_id>
    <item_title>Tag text color</item_title>
    <item_desc>Choose the text color for tags. Leave this blank if you wish to keep the default color (#999999).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>75</item_sort>
  </row>
  <row>
    <id>50</id>
    <item_id>tag_background</item_id>
    <item_title>Tag background color</item_title>
    <item_desc>Choose the tag background color. Leave blank if you wish to keep the default color (#555555).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>76</item_sort>
  </row>
  <row>
    <id>51</id>
    <item_id>tag_hover</item_id>
    <item_title>Tag hover - background color</item_title>
    <item_desc>Choose the background color of mouse-over tags. Leave blank if you wish to keep the default color (#DDDDDD).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>77</item_sort>
  </row>
  <row>
    <id>52</id>
    <item_id>comment_date_color</item_id>
    <item_title>Comment date text color</item_title>
    <item_desc>Choose the text color for comment dates in the body section of the website (content and widgets). This setting will also apply to the date in the &amp;quot;Better Recent Posts&amp;quot; widget. Leave blank if you wish to keep the default color (#818181).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>78</item_sort>
  </row>
  <row>
    <id>53</id>
    <item_id>input_background</item_id>
    <item_title>Input field background color</item_title>
    <item_desc>Choose the background color of the input fields (such as seach form and comment form) in the body section of the website (content and widgets). Leave blank if you wish to keep the default color (#555555).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>79</item_sort>
  </row>
  <row>
    <id>54</id>
    <item_id>button_background</item_id>
    <item_title>Button background color</item_title>
    <item_desc>Choose the background color of submit-type buttons in the body section of the website (content and widgets). Leave blank if you wish to keep the default color (#777777).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>80</item_sort>
  </row>
  <row>
    <id>55</id>
    <item_id>meta_color</item_id>
    <item_title>Button hover color</item_title>
    <item_desc>Choose the mouse-over background of buttons. Leave blank if you wish to keep the default color (#999999).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>81</item_sort>
  </row>
  <row>
    <id>56</id>
    <item_id>content_background</item_id>
    <item_title>Button text color</item_title>
    <item_desc>Choose the text color of submit-type buttons. Leave blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>82</item_sort>
  </row>
  <row>
    <id>62</id>
    <item_id>style_shortcodes</item_id>
    <item_title>Style: Shortcodes</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>83</item_sort>
  </row>
  <row>
    <id>63</id>
    <item_id>spoiler_two</item_id>
    <item_title>Spoiler style 2 background color</item_title>
    <item_desc>Choose the background color for shortcode-generated spoilers of style 2. Leave this blank if you wish to keep the default color (#E1E1E1).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>84</item_sort>
  </row>
  <row>
    <id>64</id>
    <item_id>div_col</item_id>
    <item_title>Divider line color</item_title>
    <item_desc>Choose the line color for the divider shortcode. Leave this blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>85</item_sort>
  </row>
  <row>
    <id>65</id>
    <item_id>tabs_one_bck</item_id>
    <item_title>Tabs style 1 - background color</item_title>
    <item_desc>Choose the background color of shortcode-generated tabs of style 1. Leave this blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>86</item_sort>
  </row>
  <row>
    <id>66</id>
    <item_id>tabs_one_background</item_id>
    <item_title>Tabs style 1 - border color</item_title>
    <item_desc>Choose the border color of shortcode-generated tabs of style 1. Leave this blank if you wish to keep the default color (#E5E5E5).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>87</item_sort>
  </row>
  <row>
    <id>67</id>
    <item_id>tabs_one_inactive_background</item_id>
    <item_title>Tabs style 1 - inactive tab background</item_title>
    <item_desc>Choose the background color for inactive tabs of shortcode-generated tabs of style 1. Leave this blank if you wish to keep the default color (#F1F1F1).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>88</item_sort>
  </row>
  <row>
    <id>68</id>
    <item_id>tabs_one_hover</item_id>
    <item_title>Tabs style 1 - tab hover background color</item_title>
    <item_desc>Choose the mouse-over background color of inactive tabs for shortcode-generated tabs of style 1. Leave this blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>89</item_sort>
  </row>
  <row>
    <id>69</id>
    <item_id>tabs_two_bck</item_id>
    <item_title>Tabs style 2 - background color</item_title>
    <item_desc>Choose the border color of shortcode-generated tabs of style 2. Leave this blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>90</item_sort>
  </row>
  <row>
    <id>70</id>
    <item_id>tabs_two_background</item_id>
    <item_title>Tabs style 2 - border color</item_title>
    <item_desc>Choose the border color of shortcode-generated tabs of style 2. Leave this blank if you wish to keep the default color (#E5E5E5).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>91</item_sort>
  </row>
  <row>
    <id>71</id>
    <item_id>tabs_two_inactive_background</item_id>
    <item_title>Tabs style 2 - inactive tab background</item_title>
    <item_desc>Choose the background color for inactive tabs of shortcode-generated tabs of style 2. Leave this blank if you wish to keep the default color (#F1F1F1).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>92</item_sort>
  </row>
  <row>
    <id>72</id>
    <item_id>tabs_two_hover</item_id>
    <item_title>Tabs style 2 - tab hover background</item_title>
    <item_desc>Choose the mouse-over background color of inactive tabs for shortcode-generated tabs of style 1. Leave this blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>93</item_sort>
  </row>
  <row>
    <id>73</id>
    <item_id>tabs_three_bck</item_id>
    <item_title>Tabs style 3 - tab background color</item_title>
    <item_desc>Choose the background color of shortcode-generated tabs of style 3. Leave this blank if you wish to keep the default color (#666666).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>94</item_sort>
  </row>
  <row>
    <id>74</id>
    <item_id>tabs_three_background</item_id>
    <item_title>Tabs style 3 - border color</item_title>
    <item_desc>Choose the border color of shortcode-generated tabs of style 3. Leave this blank if you wish to keep the default color (#E5E5E5).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>95</item_sort>
  </row>
  <row>
    <id>75</id>
    <item_id>tabs_three_hover</item_id>
    <item_title>Tabs style 3 - tab hover background</item_title>
    <item_desc>Choose the mouse-over background color of inactive tabs for shortcode-generated tabs of style 3. Leave this blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>96</item_sort>
  </row>
  <row>
    <id>76</id>
    <item_id>tables_one_outer</item_id>
    <item_title>Tables style 1 - outer border color</item_title>
    <item_desc>Choose the outer border color for shortcode-generated tables of style 1. Leave this blank if you wish to keep the default color (#CCCCCC).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>97</item_sort>
  </row>
  <row>
    <id>77</id>
    <item_id>tables_one_border</item_id>
    <item_title>Tables style 1 - inner grid and header row color</item_title>
    <item_desc>Choose the inner grid color and the header row backgorund color for shortcode-generated tables of style 1. Leave this blank if you wish to keep the default color (#E1E1E1).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>98</item_sort>
  </row>
  <row>
    <id>78</id>
    <item_id>tables_one_odd</item_id>
    <item_title>Tables style 1 - odd row background</item_title>
    <item_desc>Choose the background color of odd rows for shortcode-generated tables of style 1. Leave this blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>99</item_sort>
  </row>
  <row>
    <id>79</id>
    <item_id>tables_one_even</item_id>
    <item_title>Tables style 1 - even row background</item_title>
    <item_desc>Choose the background color of even rows for shortcode-generated tables of style 1. Leave this blank if you wish to keep the default color (#F1F1F1).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>100</item_sort>
  </row>
  <row>
    <id>80</id>
    <item_id>tables_one_font_header</item_id>
    <item_title>Tables style 1 - header row font color</item_title>
    <item_desc>Choose the text color of the header row for shortcode-generated tables of style 1. Leave this blank if you wish to keep the default color (same as the global body text color).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>101</item_sort>
  </row>
  <row>
    <id>81</id>
    <item_id>tables_one_font</item_id>
    <item_title>Tables style 1 - body text color</item_title>
    <item_desc>Choose the text color of the body rows for shortcode-generated tables of style 1. Leave this blank if you wish to keep the default color (same as the global body text color).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>102</item_sort>
  </row>
  <row>
    <id>82</id>
    <item_id>tables_two_outer</item_id>
    <item_title>Tables style 2 - outer border and header row color</item_title>
    <item_desc>Choose the outer border color and the header row backgorund color for shortcode-generated tables of style 2. Leave this blank if you wish to keep the default color (#888888).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>103</item_sort>
  </row>
  <row>
    <id>83</id>
    <item_id>tables_two_odd</item_id>
    <item_title>Tables style 2 - odd row background</item_title>
    <item_desc>Choose the background color of odd rows for shortcode-generated tables of style 2. Leave this blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>104</item_sort>
  </row>
  <row>
    <id>84</id>
    <item_id>tables_two_even</item_id>
    <item_title>Tables style 2 - even row background</item_title>
    <item_desc>Choose the background color of even rows for shortcode-generated tables of style 2. Leave this blank if you wish to keep the default color (#E2E2E2).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>105</item_sort>
  </row>
  <row>
    <id>85</id>
    <item_id>tables_two_font_header</item_id>
    <item_title>Tables style 2 - header row text color</item_title>
    <item_desc>Choose the text color of the header row for shortcode-generated tables of style 2. Leave this blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>106</item_sort>
  </row>
  <row>
    <id>86</id>
    <item_id>tables_two_font</item_id>
    <item_title>Tables style 2 - body text color</item_title>
    <item_desc>Choose the text color of the body rows for shortcode-generated tables of style 2. Leave this blank if you wish to keep the default color (same as the body text color).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>107</item_sort>
  </row>
  <row>
    <id>87</id>
    <item_id>footer</item_id>
    <item_title>Style: Footer</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>108</item_sort>
  </row>
  <row>
    <id>88</id>
    <item_id>footer_background</item_id>
    <item_title>Footer background color</item_title>
    <item_desc>Choose the background colour for the footer section of the website. Leave this blank if you wish to keep the default color (#999999);</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>109</item_sort>
  </row>
  <row>
    <id>89</id>
    <item_id>footer_background_image</item_id>
    <item_title>Footer background texture</item_title>
    <item_desc>Upload the texture image for the footer (this will override the background color setting above). Leave blank if you wish to keep the solid color fill for the footer (choose below). Leave this blank if you wish to keep the default solid background color (#999999)</item_desc>
    <item_type>upload</item_type>
    <item_options></item_options>
    <item_sort>110</item_sort>
  </row>
  <row>
    <id>90</id>
    <item_id>footer_widget_heading</item_id>
    <item_title>Footer widget heading text color</item_title>
    <item_desc>Choose the color of the headings in footer widgets. Leave blank if you wish to keep the default color (#FFFFFF).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>111</item_sort>
  </row>
  <row>
    <id>91</id>
    <item_id>footer_widget_text</item_id>
    <item_title>Footer widget text color</item_title>
    <item_desc>Choose the text color for footer widgets. Leave blank if you wish to keep the default color (#999999).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>112</item_sort>
  </row>
  <row>
    <id>92</id>
    <item_id>footer_links</item_id>
    <item_title>Footer link - text color</item_title>
    <item_desc>Choose the color of links in the footer. Leave blank if you wish to keep the default color (#A7E085).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>113</item_sort>
  </row>
  <row>
    <id>93</id>
    <item_id>footer_links_hover</item_id>
    <item_title>Footer link hover - text color</item_title>
    <item_desc>Choose the color of footer links at mouse-over. Leave blank if you wish to keep the default color (#99FF66).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>114</item_sort>
  </row>
  <row>
    <id>94</id>
    <item_id>copyright_color</item_id>
    <item_title>Copyright text color</item_title>
    <item_desc>Choose the text color for the copyright area (positioned under the footer widget area). Leave blank if you wish to keep the default color (#777777).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>115</item_sort>
  </row>
  <row>
    <id>95</id>
    <item_id>copyright_link</item_id>
    <item_title>Copyright link - text color</item_title>
    <item_desc>Choose the text color for copyright links. Leave this blank if you wish to keep the default color (#A7E085).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>116</item_sort>
  </row>
  <row>
    <id>96</id>
    <item_id>copyright_background</item_id>
    <item_title>Copyright background color</item_title>
    <item_desc>Choose the background color for the copyright section (bottom of the footer). Leave this blank if you wish to keep the default color (#555555).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>117</item_sort>
  </row>
  <row>
    <id>97</id>
    <item_id>footer_tag_text</item_id>
    <item_title>Footer tags - text color</item_title>
    <item_desc>Choose the text color of footer tags (the tag cloud widget). Leave this blank if you wish to keep the default text color (#CCCCCC).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>118</item_sort>
  </row>
  <row>
    <id>98</id>
    <item_id>footer_tag_background</item_id>
    <item_title>Footer tags - background color</item_title>
    <item_desc>Choose the background color for footer tags (the tag cloud widget). Leave this blank if wish to keep the default color (#AAAAAA).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>119</item_sort>
  </row>
  <row>
    <id>99</id>
    <item_id>footer_tag_text_hover</item_id>
    <item_title>Footer tags hover - text color</item_title>
    <item_desc>Choose the text color of footer tags on mouse-over. Leave blank if you wish to keep the default color (#999999).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>120</item_sort>
  </row>
  <row>
    <id>100</id>
    <item_id>footer_tag_background_hover</item_id>
    <item_title>Footer tags hover - background color</item_title>
    <item_desc>Choose the border color of footer tags on mouse-over. Leave blank if you wish to keep the default color (#DDDDDD).</item_desc>
    <item_type>colorpicker</item_type>
    <item_options></item_options>
    <item_sort>121</item_sort>
  </row>
  <row>
    <id>101</id>
    <item_id>customcss</item_id>
    <item_title>Style: Add Custom CSS</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>122</item_sort>
  </row>
  <row>
    <id>102</id>
    <item_id>custom_css</item_id>
    <item_title>Custom CSS</item_title>
    <item_desc>You can add your own CSS code here.</item_desc>
    <item_type>textarea</item_type>
    <item_options>16</item_options>
    <item_sort>123</item_sort>
  </row>
  <row>
    <id>103</id>
    <item_id>analytics</item_id>
    <item_title>Analytics</item_title>
    <item_desc></item_desc>
    <item_type>heading</item_type>
    <item_options></item_options>
    <item_sort>124</item_sort>
  </row>
  <row>
    <id>104</id>
    <item_id>google_analytics</item_id>
    <item_title>Google Analytics code</item_title>
    <item_desc>Input your Google Analytics tracking code here, for example UA-27193434-1.</item_desc>
    <item_type>input</item_type>
    <item_options></item_options>
    <item_sort>125</item_sort>
  </row>
</wp_fuji_option_tree>';
    $new_options = new SimpleXMLElement( $rawdata );

    // create table
    if ($new_installation) {

    $wpdb->query( "DROP TABLE $this->table_name" );    
    $wpdb->query( $this->option_tree_table( 'create' ) );

    }  

      // insert data
    foreach ( $new_options->row as $value ) 
    {
    $wpdb->insert( $this->table_name, 
      array( 
        'item_id' => $value->item_id,
        'item_title' => $value->item_title,
        'item_desc' => $value->item_desc,
        'item_type' => $value->item_type,
        'item_options' => $value->item_options
      )
    );

    }
  } 

  /*
   * Restore Table Data if empty
   *
   * @uses delete_option()
   * @uses option_tree_activate()
   * @uses wp_redirect()
   * @uses admin_url()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_restore_default_data() 
  {
    global $wpdb;

    // drop table
    $new_installation = $wpdb->get_var( "show tables like '$this->table_name'" ) != $this->table_name;

    if (!$new_installation) $wpdb->query( "DROP TABLE $this->table_name" );

    // remove activation check
    delete_option( 'option_tree_version' );

    // load DB activation function
    $this->option_tree_activate();

    // Redirect
    wp_redirect( admin_url().'admin.php?page=option_tree' );
  }

  /**
   * Add Admin Menu Items & Test Actions
   *
   * @uses option_tree_export_xml()
   * @uses option_tree_data()
   * @uses get_results()
   * @uses option_tree_restore_default_data()
   * @uses option_tree_activate()
   * @uses get_option()
   * @uses option_tree_import_xml()
   * @uses get_user_option()
   * @uses add_object_page()
   * @uses add_submenu_page()
   * @uses add_action()
   *
   * @access public
   * @since 1.0.0
   *
   * @param int $param
   *
   * @return void
   */
  function option_tree_admin() 
  {
    global $wpdb;

      // export XML - run before anything else
      if ( isset($_GET['action']) && $_GET['action'] == 'ot-export-xml' )
      option_tree_export_xml( $this->option_tree_data(), $this->table_name );

    // grab saved table option
    $new_installation = $wpdb->get_var( "show tables like '$this->table_name'" ) != $this->table_name;

    if (!$new_installation) $test_options = $wpdb->get_results( "SELECT * FROM {$this->table_name}" );

    // restore table if needed
    if ( empty( $test_options ) )
    $this->option_tree_restore_default_data();

    // upgrade DB automatically
    $this->option_tree_activate();

    // load options array
    $settings = get_option( 'option_tree' );

    // set admin color
    $icon = ( get_user_option( 'admin_color' ) == 'classic' ) ? OT_PLUGIN_URL.'/assets/images/generic.png' : OT_PLUGIN_URL.'/assets/images/generic.png';

    // create menu items
    add_menu_page( 'Theme Options', 'Theme Options', 'edit_pages', 'option_tree', array( $this, 'option_tree_options_page' ), $icon, 58.6);
    $option_tree_options = add_submenu_page( 'option_tree', 'Theme Options', 'Theme Options', 'add_users', 'option_tree', array( $this, 'option_tree_options_page' ) );
   	// $option_tree_docs = add_submenu_page( 'option_tree', 'OptionTree', 'Documentation', 'level_7', 'option_tree_docs', array( $this, 'option_tree_docs_page' ) );
   	// $option_tree_settings = add_submenu_page( 'option_tree', 'OptionTree', 'Settings', 'level_10', 'option_tree_settings', array( $this, 'option_tree_settings_page' ) );

    // add menu items
    add_action( "admin_print_styles-$option_tree_options", array( $this, 'option_tree_load' ) );
    // add_action( "admin_print_styles-$option_tree_docs", array( $this, 'option_tree_load' ) );
    // add_action( "admin_print_styles-$option_tree_settings", array( $this, 'option_tree_load' ) );
  }

  /**
   * Load Scripts & Styles
   *
   * @uses wp_enqueue_style()
   * @uses get_user_option()
   * @uses add_thickbox()
   * @uses wp_enqueue_script()
   * @uses wp_deregister_style()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_load() 
  {
    // enqueue styles
    wp_enqueue_style( 'option-tree-style', OT_PLUGIN_URL.'/assets/css/style-main.css', false, $this->version, 'screen');

    // classic admin theme styles
    if ( get_user_option( 'admin_color') == 'classic' ) 
      wp_enqueue_style( 'option-tree-style-classic', OT_PLUGIN_URL.'/assets/css/style-classic.css', array( 'option-tree-style' ), $this->version, 'screen');

    // enqueue scripts
    add_thickbox();
    wp_enqueue_script( 'jquery-table-dnd', OT_PLUGIN_URL.'/assets/js/jquery.table.dnd.js', array('jquery'), $this->version );
    wp_enqueue_script( 'jquery-color-picker', OT_PLUGIN_URL.'/assets/js/jquery.color.picker.js', array('jquery'), $this->version );
    wp_enqueue_script( 'jquery-option-tree', OT_PLUGIN_URL.'/assets/js/jquery.option.tree.js', array('jquery','media-upload','thickbox','jquery-ui-core','jquery-ui-tabs','jquery-table-dnd','jquery-color-picker', 'jquery-ui-sortable'), $this->version );

    // remove GD star rating conflicts
    wp_deregister_style( 'gdsr-jquery-ui-core' );
    wp_deregister_style( 'gdsr-jquery-ui-theme' );
  }

  /**
   * Grab the wp_option_tree table options array
   *
   * @uses get_results()
   *
   * @access public
   * @since 1.0.0
   *
   * @return array
   */
  function option_tree_data() 
  {
    global $wpdb;

    // create an array of options

    $new_installation = $wpdb->get_var( "show tables like '$this->table_name'" ) != $this->table_name;    
    if (!$new_installation)
    $db_options = $wpdb->get_results( "SELECT * FROM {$this->table_name} ORDER BY item_sort ASC" );
	if (!empty($db_options)) {
    	return $db_options;
	}
  }

  /**
   * Theme Options Page
   *
   * @uses get_option()
   * @uses get_option_page_ID()
   * @uses option_tree_check_post_lock()
   * @uses option_tree_check_post_lock()
   * @uses option_tree_notice_post_locked()
   *
   * @access public
   * @since 1.0.0
   *
   * @return string
   */
  function option_tree_options_page() 
  {
    // set 
    $ot_array = $this->option_array;

    // load saved option_tree
    $settings = get_option( 'option_tree' );

    // private page ID
    $post_id = $this->get_option_page_ID( 'media' );

    // set post lock
    if ( $last = $this->option_tree_check_post_lock( $post_id ) ) 
    {
      $message = $this->option_tree_notice_post_locked( $post_id );
      } 
      else 
      {
          $this->option_tree_set_post_lock( $post_id );
      }

    // Grab Options Page
    include( OT_PLUGIN_DIR.'/front-end/options.php' );
  }

  /**
   * Settings Page
   *
   * @uses get_option()
   * @uses get_option_page_ID()
   * @uses option_tree_check_post_lock()
   * @uses option_tree_check_post_lock()
   * @uses option_tree_notice_post_locked()
   *
   * @access public
   * @since 1.0.0
   *
   * @return string
   */
  function option_tree_settings_page() 
  {
    $ot_array = $this->option_array;

    // Load Saved Options
      $settings = get_option('option_tree');

      // private page ID
    $post_id = $this->get_option_page_ID( 'options' );

    // set post lock
    if ( $last = $this->option_tree_check_post_lock( $post_id ) ) 
    {
      $message = $this->option_tree_notice_post_locked( $post_id );
      } 
      else 
      {
          $this->option_tree_set_post_lock( $post_id );
      }

    // Get Settings Page
    include( OT_PLUGIN_DIR.'/front-end/settings.php');
  }

  /**
   * Documentation Page
   *
   * @access public
   * @since 1.0.0
   *
   * @return string
   */
  function option_tree_docs_page() 
  {
    // Get Settings Page
    include( OT_PLUGIN_DIR.'/front-end/docs.php');
  }

  /**
   * Save Theme Option via AJAX
   *
   * @uses check_ajax_referer()
   * @uses update_option()
   * @uses option_tree_set_post_lock()
   * @uses get_option_page_ID()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_array_save() 
  {
    // Check AJAX Referer
    check_ajax_referer( '_theme_options', '_ajax_nonce' );

    // set option values
    foreach ( $this->option_array as $value ) 
    {
      $key = trim( $value->item_id );
      if ( isset( $_REQUEST[$key] ) )
      { 
        $val = $_REQUEST[$key];
        $new_settings[$key] = $val;
      }
      }

      // Update Theme Options
    update_option( 'option_tree', $new_settings );
    $this->option_tree_set_post_lock( $this->get_option_page_ID( 'media' ) );

      die();

  }

  /**
   * Reset Theme Option via AJAX
   *
   * @uses check_ajax_referer()
   * @uses update_option()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_array_reset() 
  {
    // Check AJAX Referer
    check_ajax_referer( '_theme_options', '_ajax_nonce' );

    // clear option values
    foreach ( $this->option_array as $value ) 
    {
      $key = $value->item_id;
      $new_options[$key] = '';
    }

    // update theme Options
    update_option( 'option_tree', $new_options );

      die();
  }

  /**
   * Insert Row into Option Setting Table via AJAX
   *
   * @uses check_ajax_referer()
   * @uses get_results()
   * @uses insert()
   * @uses get_var()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_add() {
      global $wpdb;

    // check AJAX referer
    check_ajax_referer( 'inlineeditnonce', '_ajax_nonce' );

    // grab fresh options array
    $ot_array = $wpdb->get_results( "SELECT * FROM {$this->table_name}" );

    // get form data
    $id = $_POST['id'];
      $item_id       = htmlspecialchars(stripslashes(trim($_POST['item_id'])), ENT_QUOTES,'UTF-8',true);
      $item_title    = htmlspecialchars(stripslashes(trim($_POST['item_title'])), ENT_QUOTES,'UTF-8',true);
      $item_desc     = htmlspecialchars(stripslashes(trim($_POST['item_desc'])), ENT_QUOTES,'UTF-8',true);
      $item_type     = htmlspecialchars(stripslashes(trim($_POST['item_type'])), ENT_QUOTES,'UTF-8',true);
      $item_options  = htmlspecialchars(stripslashes(trim($_POST['item_options'])), ENT_QUOTES,'UTF-8',true);

      // validate item key
      foreach( $ot_array as $value ) 
      {
      if ( $item_id == $value->item_id ) 
      {
        die( "That option key is already in use." );
      }
      }

      // verify key is alphanumeric
    if ( eregi( '[^a-z0-9_]', $item_id ) ) 
      die("You must enter a valid option key.");

      // verify title
    if (strlen($item_title) < 1 ) 
      die("You must give your option a title.");

    if ( $item_type == 'textarea' && !is_numeric( $item_options ) )
      die("The row value must be numeric.");

    // update row
    $wpdb->insert( $this->table_name, 
      array( 
        'item_id' => $item_id,
        'item_title' => $item_title,
        'item_desc' => $item_desc,
        'item_type' => $item_type,
        'item_options' => $item_options,
        'item_sort' => $id
      )
    );

    // verify values in the DB are updated
    $updated = $wpdb->get_var(" 
      SELECT id 
      FROM {$this->table_name}
      WHERE item_id = '$item_id'
      AND item_title = '$item_title'
      AND item_type = '$item_type'
      AND item_options = '$item_options'
      ");

    // if updated
    if ( $updated )
    {
      die('updated');
    } 
    else
    {
      die("There was an error, please try again.");
    }
  }

  /**
   * Update Option Setting Table via AJAX
   *
   * @uses check_ajax_referer()
   * @uses get_results()
   * @uses update()
   * @uses get_var()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_edit() {
      global $wpdb;

    // Check AJAX Referer
    check_ajax_referer( 'inlineeditnonce', '_ajax_nonce' );

    // grab fresh options array
    $ot_array = $wpdb->get_results( "SELECT * FROM {$this->table_name}" );

    // get form data
      $id = $_POST['id'];
      $item_id       = htmlspecialchars(stripslashes(trim($_POST['item_id'])), ENT_QUOTES,'UTF-8',true);
      $item_title    = htmlspecialchars(stripslashes(trim($_POST['item_title'])), ENT_QUOTES,'UTF-8',true);
      $item_desc     = htmlspecialchars(stripslashes(trim($_POST['item_desc'])), ENT_QUOTES,'UTF-8',true);
      $item_type     = htmlspecialchars(stripslashes(trim($_POST['item_type'])), ENT_QUOTES,'UTF-8',true);
      $item_options  = htmlspecialchars(stripslashes(trim($_POST['item_options'])), ENT_QUOTES,'UTF-8',true);

      // validate item key
      foreach($ot_array as $value) 
      {
      if ( $value->item_sort == $id ) 
      {
        if ($item_id == $value->item_id && $value->item_sort != $id) 
        {
          die("That option key is already in use.");
        }
      } 
      else if ($item_id == $value->item_id && $value->id != $id) 
      {
        die("That option key is already in use.");
      }
      }

      // verify key is alphanumeric
    if ( eregi( '[^a-z0-9_]', $item_id ) ) 
      die("You must enter a valid option key.");

      // verify title
      if ( strlen( $item_title ) < 1 ) 
      die("You must give your option a title.");

    if ( $item_type == 'textarea' && !is_numeric( $item_options ) )
      die("The row value must be numeric.");

    // update row
    $wpdb->update( $this->table_name, 
      array( 
        'item_id' => $item_id, 
        'item_title' => $item_title, 
        'item_desc' => $item_desc, 
        'item_type' => $item_type, 
        'item_options' => $item_options 
      ), 
      array( 
        'id' => $id 
      )
    );

    // verify values in the DB are updated
    $updated = $wpdb->get_var(" 
      SELECT id 
      FROM {$this->table_name}
      WHERE item_id = '$item_id'
      AND item_title = '$item_title'
      AND item_type = '$item_type'
      AND item_options = '$item_options'
      ");

    // if updated
    if ( $updated ) 
    {
      die('updated');
    } 
    else 
    {
      die("There was an error, please try again.");
    }
  }

  /**
   * Remove Option via AJAX
   *
   * @uses check_ajax_referer()
   * @uses query()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_delete() 
  {
    global $wpdb;

    // check AJAX referer
    check_ajax_referer( 'inlineeditnonce', '_ajax_nonce' );

    // grab ID
      $id = $_REQUEST['id'];

    // delete item
      $wpdb->query(" 
      DELETE FROM $this->table_name 
      WHERE id = '$id'
    ");

      die('removed');
  }

  /**
   * Get Option ID via AJAX
   *
   * @uses check_ajax_referer()
   * @uses delete_post_meta()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_next_id() 
  {
    global $wpdb;

    // check AJAX referer
    check_ajax_referer( 'inlineeditnonce', '_ajax_nonce' );

    // get ID
    $id = $wpdb->get_var( "SELECT id FROM {$this->table_name} ORDER BY id DESC LIMIT 1" );

    // return ID
      die($id);
  }

  /**
   * Update Sort Order via AJAX
   *
   * @uses check_ajax_referer()
   * @uses update()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function option_tree_sort() {
    global $wpdb;

    // check AJAX referer
    check_ajax_referer( 'inlineeditnonce', '_ajax_nonce' );

    // create an array of IDs
      $fields = explode('&', $_REQUEST['id']);

      // set order
      $order = 0;

    // update the sort order
      foreach( $fields as $field ) {
          $order++;
          $key = explode('=', $field);
          $id = urldecode($key[1]);
          $wpdb->update( $this->table_name, 
        array(
          'item_sort' => $order 
        ), 
        array( 
          'id' => $id 
        )
      );
      }
      die();
  }


  /**
   * Import Option Data via AJAX
   *
   * @uses check_ajax_referer()
   * @uses update()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */

  function option_tree_add_slider() 
  {
    $count = $_GET['count'] + 1;
    $id = $_GET['slide_id'];
    $image = array(
      'order'       => $count,
      'title'       => '',
      'image'       => '',
      'link'        => '',
      'description' => ''
    );
    option_tree_slider_view( $id, $image, $this->get_option_page_ID('media'), $count );
    die();
  }

  /**
   * Returns the ID of a cutom post tpye
   *
   * @uses get_results()
   *
   * @access public
   * @since 1.0.0
   *
   * @param string $page_title
   *
   * @return int
   */
  function get_option_page_ID( $page_title = '' ) 
  {
    global $wpdb;

    return $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE post_title = '{$page_title}' AND post_type = 'option-tree' AND post_status != 'trash'");
  }

  /**
   * Register custom post type & create two posts
   *
   * @uses get_results()
   *
   * @access public
   * @since 1.0.0
   *
   * @return void
   */
  function create_option_post() 
  {
    register_post_type( 'option-tree', array(
        'labels' => array(
            'name' => __( 'Options', 'satori' ),
        ),
        'public' => true,
        'show_ui' => false,
        'capability_type' => 'post',
        'exclude_from_search' => true,
        'hierarchical' => false,
        'rewrite' => false,
        'supports' => array( 'title', 'editor' ),
        'can_export' => true,
        'show_in_nav_menus' => false,
    ) );

    // create a private page to attach media to
    if ( isset($_GET['page']) && $_GET['page'] == 'option_tree' ) 
    {  
      // look for custom page
      $page_id = $this->get_option_page_ID( 'media' );

      // no page create it
      if ( ! $page_id ) 
      {
        // create post object
        $_p = array();
        $_p['post_title'] = 'Media';
        $_p['post_status'] = 'private';
        $_p['post_type'] = 'option-tree';
        $_p['comment_status'] = 'closed';
        $_p['ping_status'] = 'closed';

        // insert the post into the database
        $page_id = wp_insert_post( $_p );
      }
    }

    // create a private page for settings page
    if ( isset($_GET['page']) && $_GET['page'] == 'option_tree_settings' ) 
    {  
      // look for custom page
      $page_id = $this->get_option_page_ID( 'options' );

      // no page create it
      if ( ! $page_id ) 
      {
        // create post object
        $_p = array();
        $_p['post_title'] = 'Options';
        $_p['post_status'] = 'private';
        $_p['post_type'] = 'option-tree';
        $_p['comment_status'] = 'closed';
        $_p['ping_status'] = 'closed';

        // insert the post into the database
        $page_id = wp_insert_post( $_p );
      }
    }
  }

  /**
   * Outputs the notice message to say that someone else is editing this post at the moment.
   *
   * @uses get_userdata()
   * @uses get_post_meta()
   * @uses esc_html()
   *
   * @access public
   * @since 1.0.0
   *
   * @param int $post_id
   *
   * @return string
   */
  function option_tree_notice_post_locked( $post_id ) 
  {
    if ( !$post_id )
          return false;

      $last_user = get_userdata( get_post_meta( $post_id, '_edit_last', true ) );
    $last_user_name = $last_user ? $last_user->display_name : __('Somebody','satori');
    $the_page = ( $_GET['page'] == 'option_tree' ) ? __('Theme Options','satori') : __('Settings','satori');

    $message = sprintf( __( 'Warning: %s is currently editing the %s.' ,'satori'), esc_html( $last_user_name ), $the_page );
    return '<div class="message warning"><span>&nbsp;</span>'.$message.'</div>';
  }

  /**
   * Check to see if the post is currently being edited by another user.
   *
   * @uses get_post_meta()
   * @uses apply_filters()
   * @uses get_current_user_id()
   *
   * @access public
   * @since 1.0.0
   *
   * @param int $post_id
   *
   * @return bool
   */
  function option_tree_check_post_lock( $post_id ) 
  { 
      if ( !$post_id )
          return false;

      $lock = get_post_meta( $post_id, '_edit_lock', true );
      $last = get_post_meta( $post_id, '_edit_last', true );

      $time_window = apply_filters( 'wp_check_post_lock_window', 30 );

      if ( $lock && $lock > time() - $time_window && $last != get_current_user_id() )
          return $last;

      return false;
  }

  /**
   * Mark the post as currently being edited by the current user
   *
   * @uses update_post_meta()
   * @uses get_current_user_id()
   *
   * @access public
   * @since 1.0.0
   *
   * @param int $post_id
   *
   * @return bool
   */
  function option_tree_set_post_lock( $post_id ) 
  {
      if ( !$post_id )
          return false;

      if ( 0 == get_current_user_id() )
          return false;

      $now = time();

      update_post_meta( $post_id, '_edit_lock', $now );
      update_post_meta( $post_id, '_edit_last', get_current_user_id() );
  }

  /**
   * Remove the post lock
   *
   * @uses delete_post_meta()
   *
   * @access public
   * @since 1.0.0
   *
   * @param int $post_id
   *
   * @return bool
   */
  function option_tree_remove_post_lock( $post_id ) 
  {
      if ( !$post_id )
          return false;

      delete_post_meta( $post_id, '_edit_lock' );
      delete_post_meta( $post_id, '_edit_last' );
  }

}

?>